@@ -1,14 +1,15 @@
 /*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2016 NAN contributors
+ * Copyright (c) 2018 NAN contributors
  *
  * MIT License <https://github.com/nodejs/nan/blob/master/LICENSE.md>
  ********************************************************************/
 
 const test     = require('tap').test
     , testRoot = require('path').resolve(__dirname, '..')
-    , bindings = require('bindings')({ module_root: testRoot, bindings: 'weak2' });
+    , bindings = require('bindings')({ module_root: testRoot, bindings: 'weak2' })
+    , gc = require('./gc-fn');
 
 test('weak2', function (t) {
   t.plan(3);
